package com.gmail.alexander;

import com.vaadin.flow.component.button.Button;
import com.vaadin.flow.component.dependency.HtmlImport;
import com.vaadin.flow.component.grid.Grid;
import com.vaadin.flow.component.icon.Icon;
import com.vaadin.flow.component.icon.VaadinIcon;
import com.vaadin.flow.component.notification.Notification;
import com.vaadin.flow.component.orderedlayout.HorizontalLayout;
import com.vaadin.flow.component.orderedlayout.VerticalLayout;
import com.vaadin.flow.component.textfield.TextField;
import com.vaadin.flow.data.value.ValueChangeMode;
import com.vaadin.flow.router.Route;

/**
 * The main view contains a button and a click listener.
 */
//@HtmlImport("styles/shared-styles.html")
@Route("")
public class MainView extends VerticalLayout {

    private TextField filterText = new TextField();

    private CustomerForm form = new CustomerForm(this);

    // Add the next two lines:
    private CustomerService service = CustomerService.getInstance();
    private Grid<Customer> grid = new Grid<>();


    public MainView() {


        // Фильтр
        filterText.setPlaceholder("Filter by name...");
        filterText.setValueChangeMode(ValueChangeMode.EAGER);
        filterText.addValueChangeListener(e -> updateList());

        // Кнопка очистки фильтра
        Button clearFilterTextBtn = new Button(new Icon(VaadinIcon.CLOSE_CIRCLE));
        clearFilterTextBtn.addClickListener(e -> filterText.clear());

        // Раскладка для фильтра и кнопки
        //HorizontalLayout filtering = new HorizontalLayout(filterText, clearFilterTextBtn);

        Button addCustomerBtn = new Button("Add new customer");
        addCustomerBtn.addClickListener(e -> {
            grid.asSingleSelect().clear();
            form.setCustomer(new Customer());
        });

        HorizontalLayout toolbar = new HorizontalLayout(filterText, clearFilterTextBtn, addCustomerBtn);





        // Грид
        grid.setSizeFull();
        grid.setMultiSort(true);
        grid.addColumn(Customer::getFirstName).setHeader("First name");
        grid.addColumn(Customer::getLastName).setHeader("Last name");
        grid.addColumn(Customer::getStatus).setHeader("Status");
        grid.asSingleSelect().addValueChangeListener(event -> {
            form.setCustomer(event.getValue());
        });


        //add(filtering, grid);
        HorizontalLayout main = new HorizontalLayout(grid, form);
        main.setAlignItems(Alignment.START);
        main.setSizeFull();
        add(toolbar, main);

        setHeight("100vh");
        updateList();
    }


    public void updateList() {
        //grid.setItems(service.findAll());
        grid.setItems(service.findAll(filterText.getValue()));
    }

}
