package com.gmail.alexander.jetty;

import org.eclipse.jetty.http.HttpScheme;
import org.eclipse.jetty.server.*;
import org.eclipse.jetty.servlet.ServletContextHandler;
import org.eclipse.jetty.servlet.ServletHolder;
import org.eclipse.jetty.websocket.jsr356.server.deploy.WebSocketServerContainerInitializer;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Start Jetty server embedded
 */
public class JettyServ {

    private static final Logger logger = LoggerFactory.getLogger(JettyServ.class);

    private String httpHost = "localhost";
    private int httpPort = 9998;
    private String webContextApplication = "/";


    /**
     * Конструктор
     */
    public JettyServ() {
    }


    public void init() {

        try {
            Server server = new Server();

            ServletContextHandler servletContextHandlerApplication = createServletContextHandlerApplication();
            server.setHandler(servletContextHandlerApplication);

            WebSocketServerContainerInitializer.configureContext(servletContextHandlerApplication);

            try {
                ServerConnector httpConnector = createHTTPConnector(server);
                server.addConnector(httpConnector);
                server.start();
            } catch (Exception ex) {
                logger.error("Error Jetty start", ex);
            }
        } catch (Exception e){
            logger.error("Error Jetty initialize.", e);
        }


    }


    /**
     * ServletContextHandler initializer
     */
    private ServletContextHandler createServletContextHandlerApplication() {
        ServletContextHandler servletContextHandler = new ServletContextHandler(ServletContextHandler.SESSIONS);
        servletContextHandler.setContextPath(webContextApplication);
        servletContextHandler.setInitParameter("ui", MyUI.class.getCanonicalName());
        servletContextHandler.addServlet(new ServletHolder(new MyServlet()), "/*");
        return servletContextHandler;
    }




    /**
     * Connector HTTP
     */
    private ServerConnector createHTTPConnector(Server server) {
        // HTTP Configuration for HTTP
        HttpConfiguration http_config = new HttpConfiguration();
        http_config.setSecureScheme(HttpScheme.HTTP.asString());

        http_config.setSecurePort(httpPort);
        http_config.setSendServerVersion(false);
        http_config.setSendDateHeader(false);

        // HTTP Configuration
        HttpConfiguration https_config = new HttpConfiguration(http_config);
        https_config.addCustomizer(new SecureRequestCustomizer());

        // Connector
        ServerConnector httpConnector = new ServerConnector(server, new HttpConnectionFactory(https_config));

        httpConnector.setHost(httpHost);
        httpConnector.setPort(httpPort);

        return httpConnector;
    }


}
